@@ -12,16 +12,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from beartype.typing import Any, Sequence
+from beartype.typing import Any
 
 
 class MathUtil:
-    @staticmethod
-    def get_max_signed_sum(values: Sequence[int | float]) -> float:
-        over_0 = sum(val for val in values if val > 0)
-        below_0 = abs(sum(val for val in values if val < 0))
-        return max(below_0, over_0)
-
     @staticmethod
     def convert_float_typed_integers_to_int(value: float | Any) -> int | Any:
         if isinstance(value, float) and value.is_integer():
