@@ -20,6 +20,7 @@ from typing_extensions import override
 from superlinked.framework.common.dag.context import ExecutionContext
 from superlinked.framework.common.dag.number_embedding_node import NumberEmbeddingNode
 from superlinked.framework.common.data_types import Vector
+from superlinked.framework.common.exception import InvalidStateException
 from superlinked.framework.common.space.config.embedding.number_embedding_config import (
     Mode,
     NumberEmbeddingConfig,
@@ -27,7 +28,6 @@ from superlinked.framework.common.space.config.embedding.number_embedding_config
 from superlinked.framework.common.space.normalization.normalization_factory import (
     NormalizationFactory,
 )
-from superlinked.framework.query.dag.exception import QueryEvaluationException
 from superlinked.framework.query.dag.query_embedding_orphan_node import (
     QueryEmbeddingOrphanNode,
 )
@@ -77,13 +77,13 @@ class QueryNumberEmbeddingNode(QueryEmbeddingOrphanNode[float, NumberEmbeddingNo
         if not corresponding_inputs:
             return None
         if len(corresponding_inputs) > 1:
-            raise QueryEvaluationException(
+            raise InvalidStateException(
                 f"Number embedding node with mode {self._embedding_config.mode} "
                 f"can only handle a single input, got {len(corresponding_inputs)}."
             )
         input_value = corresponding_inputs[0].value
         if not isinstance(input_value.item, Vector):
-            raise QueryEvaluationException(
+            raise InvalidStateException(
                 f"Number embedding node with mode {self._embedding_config.mode} "
                 f"can only handle a Vector input, got {type(input_value.item).__name__}."
             )
