@@ -17,9 +17,9 @@ import numpy as np
 from beartype.typing import Any, Callable, Sequence, TypeVar
 
 from superlinked.framework.common.data_types import Vector
+from superlinked.framework.common.exception import NotImplementedException
 from superlinked.framework.common.precision import Precision
 from superlinked.framework.common.schema.blob_information import BlobInformation
-from superlinked.framework.common.storage.exception import EncoderException
 from superlinked.framework.common.storage.field.field import Field
 from superlinked.framework.common.storage.field.field_data import FieldData
 from superlinked.framework.common.storage.field.field_data_type import FieldDataType
@@ -82,9 +82,9 @@ class QdrantFieldEncoder:
     def encode_field(self, field: FieldData) -> QdrantEncodedTypes:
         if encoder := self._encode_map.get(field.data_type):
             return encoder(field.value)
-        raise EncoderException(f"Unknown field type: {field.data_type}, cannot encode field.")
+        raise NotImplementedException(f"Unknown field type: {field.data_type}, cannot encode field.")
 
     def decode_field(self, field: Field, value: Any) -> FieldData:
         if decoder := self._decode_map.get(field.data_type):
             return FieldData.from_field(field, decoder(value))
-        raise EncoderException(f"Unknown field type: {field.data_type}, cannot decode field.")
+        raise NotImplementedException(f"Unknown field type: {field.data_type}, cannot decode field.")
